==> artemis_cupps-0.0.41.tar.gz: lib/utility/logger.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:open_file/open_file.dart';
import 'package:path_provider/path_provider.dart';

class Logger {
  Logger._();

  static Map<String, DateTime> lastLogs = {};
  static DateTime intiLogTime = DateTime.now();

  static Future<String> get _localPath async {
    final directory = await getApplicationDocumentsDirectory();
    return directory.path;
  }

  static Future<void> writeToLog(String logMsg, {required String from, required String to, required String logSuffix}) async {
    String today = DateTime.now().toString().substring(0, 10);
    final path = await _localPath;
    File platformLog = File('$path/${logSuffix}_$today.txt');

    String logHeader =
        '\n${DateTime.now().toString().substring(0, 24)} (${DateTime.now().difference(lastLogs[logSuffix] ?? intiLogTime)}) Send to: $to From'
        ' $from\n';
    String logFooter = "\n" + List.generate(150, (index) => "=").join() + "\n";
    lastLogs[logSuffix] = DateTime.now();
    String logText = logHeader + logMsg + logFooter;
    log(logText);
    platformLog.writeAsString(logText, mode: FileMode.append);
  }

  static Future<List<LogEntity>> getLogList([DateTime? date]) async {
    try {
      final path = await _localPath;
      return Directory(path).listSync().map((e) => LogEntity(e.path)).toList();
    } catch (e) {
      return [];
    }
  }
}

class LogEntity {
  final String path;

  LogEntity(this.path);

  Future<void> download() async {
    try {
      await OpenFile.open(path);
    } catch (e) {
      log("$e");
    }
  }

  Future<void> clear() async {
    try {
      await File(path).delete();
    } catch (e) {
      log("$e");
    }
  }

  String get name {
    try {
      String fileName = path.split("/").last;
      return fileName;
    } catch (e) {
      log("$e");
      return e.toString();
    }
  }

  String get type {
    try {
      String fileName = path.split("/").last;
      return fileName.split("_").first;
    } catch (e) {
      log("$e");
      return e.toString();
    }
  }

  String get dateStr {
    try {
      String fileName = path.split("/").last;
      return fileName.split("_").last.split(".").first;
    } catch (e) {
      log("$e");
      return e.toString();
    }
  }

  DateTime get date {
    try {
      String fileName = path.split("/").last;
      return DateTime.parse(fileName.split("_").last);
    } catch (e) {
      log("$e");
      rethrow;
    }
  }
}

==> artemis_cupps-0.0.62.tar.gz: lib/utility/logger.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:open_file/open_file.dart';
import 'package:path_provider/path_provider.dart';

class Logger {
  Logger._();

  static Map<String, DateTime> lastLogs = {};
  static DateTime intiLogTime = DateTime.now();

  static Future<String> get _localPath async {
    final directory = await getApplicationDocumentsDirectory();
    return directory.path;
  }

  static Future<void> writeToLog(String logMsg, {required String from, required String to, required String logSuffix}) async {
    String today = DateTime.now().toString().substring(0, 10);
    final path = await _localPath;
    File platformLog = File('$path/${logSuffix}_$today.txt');

    String logHeader =
        '\n${DateTime.now().toString().substring(0, 20)} (${DateTime.now().difference(lastLogs[logSuffix] ?? intiLogTime)}) Send'
        ' to: $to From'
        ' $from\n';
    String logFooter = "\n" + List.generate(150, (index) => "=").join() + "\n";
    lastLogs[logSuffix] = DateTime.now();
    String logText = logHeader + logMsg + logFooter;
    log(logText);
    platformLog.writeAsString(logText, mode: FileMode.append);
  }

  static Future<List<LogEntity>> getLogList([DateTime? date]) async {
    try {
      final path = await _localPath;
      return Directory(path).listSync().map((e) => LogEntity(e.path)).toList();
    } catch (e) {
      return [];
    }
  }

  static Future<void> generalLog(String logMsg, {String from = "Console", String to = "Log"}) async {
    String today = DateTime.now().toString().substring(0, 10);
    final path = await _localPath;
    File platformLog = File('$path/General_$today.txt');

    String logHeader =
        '\n${DateTime.now().toString().substring(0, 20)} (${DateTime.now().difference(lastLogs["General"] ?? intiLogTime)}) Send'
        ' to: $to From'
        ' $from\n';
    String logFooter = "\n" + List.generate(45, (index) => "=").join() + "\n";
    lastLogs["General"] = DateTime.now();
    String logText = logHeader + logMsg + logFooter;
    // log(logText);
    platformLog.writeAsString(logText, mode: FileMode.append);
  }


}

class LogEntity {
  final String path;

  LogEntity(this.path);

  Future<void> download() async {
    try {
      await OpenFile.open(path);
    } catch (e) {
      log("$e");
    }
  }

  Future<void> clear() async {
    try {
      await File(path).delete();
    } catch (e) {
      log("$e");
    }
  }

  String get name {
    try {
      String fileName = path.split("/").last;
      return fileName;
    } catch (e) {
      log("$e");
      return e.toString();
    }
  }

  String get type {
    try {
      String fileName = path.split("/").last;
      return fileName.split("_").first;
    } catch (e) {
      log("$e");
      return e.toString();
    }
  }

  String get dateStr {
    try {
      String fileName = path.split("/").last;
      return fileName.split("_").last.split(".").first;
    } catch (e) {
      log("$e");
      return e.toString();
    }
  }

  DateTime get date {
    try {
      String fileName = path.split("/").last;
      return DateTime.parse(fileName.split("_").last);
    } catch (e) {
      log("$e");
      rethrow;
    }
  }
}
